# Map and Unordered Map

Both of these classes inherit from the ``std::map`` and ``std::unordered_map`` classes respectively, implementing a
few additional features to make them easier to use and more versatile.

For the full documentation on the ``std::map`` and ``std::unordered_map`` classes, see
the [C++ reference](https://en.cppreference.com/w/cpp/container/map)
and [C++ reference](https://en.cppreference.com/w/cpp/container/unordered_map) pages.

```{doxygenfile} librapid/include/librapid/utilities/map.hpp
```
